.. _fanc-modules:

====================
FAN-C Python modules
====================

.. toctree::
   :maxdepth: 2

   init <modules/init>
   map <modules/map>
   regions <modules/regions>
   pairs <modules/pairs>
   matrix <modules/matrix>
   hic <modules/hic>
   peaks <modules/peaks>
   compatibility <modules/compatibility>
   architecture <modules/architecture>
   plotting <modules/plotting>
   tools <modules/tools>